==> lsst_daf_butler-27.2024.3700.tar.gz: lsst_daf_butler-27.2024.3700/python/lsst/daf/butler/registry/queries/expressions/parser/parser.py <==
# This file is part of daf_butler.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from __future__ import annotations

from .exprTree import Node
from .parserYacc import ParserYacc  # type: ignore


def parse_expression(expression: str) -> Node | None:
    """Given a Butler query expression string, convert it to a tree form.

    Parameters
    ----------
    expression : `str`
        Query string.

    Returns
    -------
    node : `Node` or `None`
        Tree form of expression query.
    """
    parser = ParserYacc()
    return parser.parse(expression)

==> lsst_daf_butler-29.0.1rc1.tar.gz: lsst_daf_butler-29.0.1rc1/python/lsst/daf/butler/registry/queries/expressions/parser/parser.py <==
# This file is part of daf_butler.
#
# Developed for the LSST Data Management System.
# This product includes software developed by the LSST Project
# (https://www.lsst.org).
# See the COPYRIGHT file at the top-level directory of this distribution
# for details of code ownership.
#
# This software is dual licensed under the GNU General Public License and also
# under a 3-clause BSD license. Recipients may choose which of these licenses
# to use; please see the files gpl-3.0.txt and/or bsd_license.txt,
# respectively.  If you choose the GPL option then the following text applies
# (but note that there is still no warranty even if you opt for BSD instead):
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

from __future__ import annotations

from .exprTree import Node
from .parserYacc import ParserYacc


def parse_expression(expression: str) -> Node | None:
    """Given a Butler query expression string, convert it to a tree form.

    Parameters
    ----------
    expression : `str`
        Query string.

    Returns
    -------
    node : `Node` or `None`
        Tree form of expression query.
    """
    parser = ParserYacc()
    return parser.parse(expression)
